CodeSource class

The location where the source code files provided with the project request are stored. AWS CodeStar retrieves the files during project creation.

Constructors

CodeSource({required S3Location s3})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3 → S3Location
Information about the Amazon S3 location where the source code files provided with the project request are stored.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited