CreateProjectResult class

Constructors

CreateProjectResult({required String arn, required String id, String? clientRequestToken, String? projectTemplateId})
CreateProjectResult.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String
The Amazon Resource Name (ARN) of the created project.
final
clientRequestToken → String?
A user- or system-generated token that identifies the entity that requested project creation.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the project.
final
projectTemplateId → String?
Reserved for future use.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited