CreateUserProfileResult class

Constructors

CreateUserProfileResult({required String userArn, DateTime? createdTimestamp, String? displayName, String? emailAddress, DateTime? lastModifiedTimestamp, String? sshPublicKey})
CreateUserProfileResult.fromJson(Map<String, dynamic> json)
factory

Properties

createdTimestamp → DateTime?
The date the user profile was created, in timestamp format.
final
displayName → String?
The name that is displayed as the friendly name for the user in AWS CodeStar.
final
emailAddress → String?
The email address that is displayed as part of the user's profile in AWS CodeStar.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTimestamp → DateTime?
The date the user profile was last modified, in timestamp format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sshPublicKey → String?
The SSH public key associated with the user in AWS CodeStar. This is the public portion of the public/private keypair the user can use to access project resources if a project owner allows the user remote access to those resources.
final
userArn → String
The Amazon Resource Name (ARN) of the user in IAM.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited