DeleteProjectResult class

Constructors

DeleteProjectResult({String? projectArn, String? stackId})
DeleteProjectResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectArn → String?
The Amazon Resource Name (ARN) of the deleted project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ID of the primary stack in AWS CloudFormation that will be deleted as part of deleting the project and its resources.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited