DescribeProjectResult class

Constructors

DescribeProjectResult({String? arn, String? clientRequestToken, DateTime? createdTimeStamp, String? description, String? id, String? name, String? projectTemplateId, String? stackId, ProjectStatus? status})
DescribeProjectResult.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) for the project.
final
clientRequestToken → String?
A user- or system-generated token that identifies the entity that requested project creation.
final
createdTimeStamp → DateTime?
The date and time the project was created, in timestamp format.
final
description → String?
The description of the project, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the project.
final
name → String?
The display name for the project.
final
projectTemplateId → String?
The ID for the AWS CodeStar project template used to create the project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackId → String?
The ID of the primary stack in AWS CloudFormation used to generate resources for the project.
final
status → ProjectStatus?
The project creation or deletion status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited