ListProjectsResult class

Constructors

ListProjectsResult({required List<ProjectSummary> projects, String? nextToken})
ListProjectsResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The continuation token to use when requesting the next set of results, if there are more results to be returned.
final
projects → List<ProjectSummary>
A list of projects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited