ListUserProfilesResult class

Constructors

ListUserProfilesResult({required List<UserProfileSummary> userProfiles, String? nextToken})
ListUserProfilesResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The continuation token to use when requesting the next set of results, if there are more results to be returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfiles → List<UserProfileSummary>
All the user profiles configured in AWS CodeStar for an AWS account.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited