ProjectStatus class

An indication of whether a project creation or deletion is failed or successful.

Constructors

ProjectStatus({required String state, String? reason})
ProjectStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String?
In the case of a project creation or deletion failure, a reason for the failure.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
The phase of completion for a project creation or deletion.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited