Toolchain class

The toolchain template file provided with the project request. AWS CodeStar uses the template to provision the toolchain stack in AWS CloudFormation.

Constructors

Toolchain({required ToolchainSource source, String? roleArn, Map<String, String>? stackParameters})

Properties

hashCode → int
The hash code for this object.
no setterinherited
roleArn → String?
The service role ARN for AWS CodeStar to use for the toolchain template during stack provisioning.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ToolchainSource
The Amazon S3 location where the toolchain template file provided with the project request is stored. AWS CodeStar retrieves the file during project creation.
final
stackParameters → Map<String, String>?
The list of parameter overrides to be passed into the toolchain template during stack provisioning, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited